@@ -338,42 +338,6 @@ BackgroundWriterMain(void)
 	 */
 	PG_SETMASK(&UnBlockSig);
 
-	if (enableSigres == true) {
-		for (;;) {
-			if (!PostmasterIsAlive(true))
-				exit(1);
-
-			/*
-			 * Process any requests or signals received recently.
-			 */
-			AbsorbFsyncRequests();
-
-			if (got_SIGHUP)
-			{
-				got_SIGHUP = false;
-				ProcessConfigFile(PGC_SIGHUP);
-			}
-			if (shutdown_requested)
-			{
-				/*
-				 * From here on, elog(ERROR) should end with exit(1), not send
-				 * control back to the sigsetjmp block above
-				 */
-				ExitOnAnyError = true;
-				/* Close down the database */
-				ShutdownXLOG(0, 0);
-				DumpFreeSpaceMap(0, 0);
-
-				remove(BGWRITER_PIDFILE);  /* SIGRES */
-
-				/* Normal exit from the bgwriter is here */
-				proc_exit(0);   /* done */
-			}
-
-			usleep(100000L);
-		}
-	}
-
 	/*
 	 * Loop forever
 	 */
@@ -428,6 +392,7 @@ BackgroundWriterMain(void)
 		 */
 		now = time(NULL);
 		elapsed_secs = now - last_checkpoint_time;
+
 		if (elapsed_secs >= CheckPointTimeout)
 			do_checkpoint = true;
 
@@ -457,7 +422,6 @@ BackgroundWriterMain(void)
 			 */
 			ckpt_active = true;
 			BgWriterShmem->ckpt_started++;
-
 			CreateCheckPoint(false, force_checkpoint);
 
 			/*
